@@ -1,5 +1,6 @@
 from __future__ import annotations
 from typing import Any, TYPE_CHECKING, Callable, TypeVar, overload, Generic, Union
+from typing_extensions import Literal
 from pathlib import Path
 import datetime
 import sys
@@ -10,11 +11,12 @@ from magicgui.widgets import create_widget
 from magicgui.widgets._bases import Widget, ValueWidget
 from magicgui.widgets._bases.value_widget import UNSET
 
-from .gui.mgui_ext import AbstractAction, Action, WidgetAction
+from .gui.mgui_ext import Action, WidgetAction
 
 if TYPE_CHECKING:
     from magicgui.widgets._protocols import WidgetProtocol
     from .gui._base import MagicTemplate
+    from .gui.mgui_ext import AbstractAction
 
     _M = TypeVar("_M", bound=MagicTemplate)
 
@@ -130,19 +132,15 @@ class MagicField(Field, Generic[_W, _V]):
         """Make a function that get the value of Widget or Action."""
         return lambda w: self.guis[id(obj)].value
 
-    # NOTE: Ideally these overload is needed for
-    # >>> @B.field.connect
-    # but in tern this will disable
-    # >>> self.B.field.value
-    # @overload
-    # def __get__(self, obj: Literal[None], objtype=None) -> MagicField[_W, _V]:
-    #     ...
-
-    # @overload
-    # def __get__(self, obj: Any, objtype=None) -> _W:
-    #     ...
+    @overload
+    def __get__(self, obj: Literal[None], objtype=None) -> MagicField[_W, _V] | _W:
+        ...
 
+    @overload
     def __get__(self, obj: Any, objtype=None) -> _W:
+        ...
+
+    def __get__(self, obj, objtype=None):
         """Get widget for the object."""
         if obj is None:
             return self
@@ -231,6 +229,56 @@ class MagicField(Field, Generic[_W, _V]):
         self.callbacks.pop(i)
         return None
 
+    def wraps(
+        self,
+        method: Callable | None = None,
+        *,
+        template: Callable | None = None,
+        copy: bool = False,
+    ):
+        """
+        Call the ``wraps`` class method of magic class.
+
+        This method is needed when a child magic class is defined outside the main magic
+        class, and integrated into the main magic class by ``field`` function, like below
+
+        .. code-block:: python
+
+            @magicclass
+            class B:
+                def func(self): ...  # pre-definition
+
+            @magicclass
+            class A:
+                b = field(B)
+
+                @b.wraps
+                def func(self):
+                    # do something
+
+        Parameters
+        ----------
+        method : Callable, optional
+            Method of parent class.
+        template : Callable, optional
+            Function template for signature.
+        copy: bool, default is False
+            If true, wrapped method is still enabled.
+
+        Returns
+        -------
+        Callable
+            Same method as input, but has updated signature.
+        """
+        from .gui._base import BaseGui
+
+        cls = self.default_factory
+        if not (isinstance(cls, type) and issubclass(cls, BaseGui)):
+            raise TypeError(
+                "The wraps method cannot be used for any objects but magic class."
+            )
+        return cls.wraps(method=method, template=template, copy=copy)
+
     @property
     def value(self) -> Any:
         return UNSET if self.default is MISSING else self.default
@@ -253,17 +301,8 @@ class MagicField(Field, Generic[_W, _V]):
             wcls = get_widget_class(value=self.value, annotation=self.annotation)
         return wcls.__name__
 
-    def decode_string_annotation(self, annot: str) -> MagicField:
-        """Convert string type annotation into field info."""
-        self.default_factory = annot
-        # Sometimes annotation is not type but str.
-        from pydoc import locate
 
-        self.default_factory = locate(self.default_factory)
-        return self
-
-
-class MagicValueField(MagicField, Generic[_W, _V]):
+class MagicValueField(MagicField[_W, _V]):
     """
     Field class for magicgui construction. Unlike MagicField, object of this class always
     returns value itself.
@@ -279,7 +318,15 @@ class MagicValueField(MagicField, Generic[_W, _V]):
 
         return widget
 
+    @overload
+    def __get__(self, obj: Literal[None], objtype=None) -> MagicValueField[_W, _V]:
+        ...
+
+    @overload
     def __get__(self, obj: Any, objtype=None) -> _V:
+        ...
+
+    def __get__(self, obj, objtype=None):
         if obj is None:
             return self
         return self.get_widget(obj).value
@@ -415,27 +462,40 @@ def field(
 
 @overload
 def vfield(
-    obj: type[_V],
+    obj: _X,
     *,
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
     enabled: bool = True,
     record: bool = True,
-) -> MagicValueField[Widget, _V]:
+) -> MagicValueField[ValueWidget, _X]:
     ...
 
 
 @overload
 def vfield(
-    obj: _V,
+    obj: type[_W],
     *,
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
     enabled: bool = True,
     record: bool = True,
-) -> MagicValueField[Widget, _V]:
+) -> MagicValueField[_W, Any]:
+    ...
+
+
+@overload
+def vfield(
+    obj: type[_X],
+    *,
+    name: str = "",
+    widget_type: str | type[WidgetProtocol] | None = None,
+    options: dict[str, Any] = {},
+    enabled: bool = True,
+    record: bool = True,
+) -> MagicValueField[ValueWidget, _X]:
     ...
 
 
