@@ -346,11 +346,13 @@ class MagicTemplate:
             Method of parent class.
         template : Callable, optional
             Function template for signature.
+        copy: bool, default is False
+            If true, wrapped method is still enabled.
 
         Returns
         -------
         Callable
-            Same method as input, but has updated signature to hide the button.
+            Same method as input, but has updated signature.
         """
         if (not copy) and get_additional_option(method, "into", None) is not None:
             # If method is already wrapped, wraps should create a copy.
@@ -641,23 +643,19 @@ class MagicTemplate:
                     # deal with popup mode.
                     if self._popup_mode not in (PopUpMode.popup, PopUpMode.dock):
                         mgui.label = ""
-                        mgui.name = (
-                            f"mgui-{id(mgui._function)}"  # to avoid name collision
-                        )
+                        # to avoid name collision
+                        mgui.name = f"mgui-{id(mgui._function)}"
                         mgui.margins = (0, 0, 0, 0)
                         title = Separator(
                             orientation="horizontal", text=text, button=True
                         )
                         title.btn_text = "-"
-                        title.btn_clicked.connect(
-                            mgui.hide
-                        )  # TODO: should remove mgui from self?
+                        # TODO: should remove mgui from self?
+                        title.btn_clicked.connect(mgui.hide)
                         mgui.insert(0, title)
                         mgui.append(Separator(orientation="horizontal"))
 
-                        if self._popup_mode == PopUpMode.popup:
-                            pass
-                        elif self._popup_mode == PopUpMode.parentlast:
+                        if self._popup_mode == PopUpMode.parentlast:
                             parent_self = self._search_parent_magicclass()
                             parent_self.append(mgui)
                         elif self._popup_mode == PopUpMode.first:
@@ -769,6 +767,8 @@ class BaseGui(MagicTemplate):
 
 
 class ContainerLikeGui(BaseGui, mguiLike, MutableSequence):
+    # This class enables similar API between magicgui widgets and additional widgets
+    # in magicclass such as menu and toolbar.
     _component_class = Action
     changed = Signal(object)
     _list: list[AbstractAction | ContainerLikeGui]
@@ -802,14 +802,12 @@ class ContainerLikeGui(BaseGui, mguiLike, MutableSequence):
             )
 
     def _create_widget_from_field(self, name: str, fld: MagicField):
-        cls = self.__class__
         if fld.not_ready():
-            try:
-                fld.decode_string_annotation(cls.__annotations__[name])
-            except (AttributeError, KeyError):
-                pass
+            raise TypeError(
+                f"MagicField {name} does not contain enough information for widget creation"
+            )
 
-        fld.name = fld.name or name.replace("_", " ")
+        fld.name = fld.name or name
         action = fld.get_action(self)
 
         if action.support_value:
@@ -1159,8 +1157,8 @@ def _child_that_has_widget(
     return child_instance
 
 
-def _method_as_getter(self, bound_value: Callable):
-    qualname = bound_value.__qualname__
+def _method_as_getter(self, getter: Callable):
+    qualname = getter.__qualname__
     _locals = "<locals>."
     if _locals in qualname:
         qualname = qualname.split(_locals)[-1]
@@ -1168,16 +1166,16 @@ def _method_as_getter(self, bound_value: Callable):
 
     def _func(w):
         ins = self
-        while clsnames[0] != ins.__class__.__name__:
-            ins = getattr(ins, "__magicclass_parent__", None)
-            if ins is None:
-                ns = ".".join(clsnames)
-                raise ValueError(
-                    f"Method {funcname} is in namespace {ns}, so it is invisible "
-                    f"from magicclass {self.__class__.__qualname__}"
-                )
+        self_cls = ins.__class__.__name__
+        if self_cls not in clsnames:
+            ns = ".".join(clsnames)
+            raise ValueError(
+                f"Method {funcname} is in namespace {ns}, so it is invisible "
+                f"from magicclass {self.__class__.__qualname__}"
+            )
+        i = clsnames.index(self_cls)
 
-        for clsname in clsnames[1:]:
+        for clsname in clsnames[i + 1 :]:
             ins = getattr(ins, clsname)
         return getattr(ins, funcname)(w)
 
