@@ -60,16 +60,19 @@ class ClassGuiBase(BaseGui):
     native: QWidget
 
     def _create_widget_from_field(self, name: str, fld: MagicField):
-        cls = self.__class__
         if fld.not_ready():
-            try:
-                fld.decode_string_annotation(cls.__annotations__[name])
-            except (AttributeError, KeyError):
-                pass
+            raise TypeError(
+                f"MagicField {name} does not contain enough information for widget creation"
+            )
 
-        fld.name = fld.name or name.replace("_", " ")
+        fld.name = fld.name or name
         widget = fld.get_widget(self)
 
+        if isinstance(widget, BaseGui):
+            widget.__magicclass_parent__ = self
+            self.__magicclass_children__.append(widget)
+            widget._my_symbol = Symbol(name)
+
         if isinstance(widget, (ValueWidget, ContainerWidget)):
             # If the field has callbacks, connect it to the newly generated widget.
             if (
@@ -165,7 +168,9 @@ class ClassGuiBase(BaseGui):
                                 )
 
                     widget.native.setParent(self._menubar, widget.native.windowFlags())
-                    self._menubar.addMenu(widget.native)
+                    self._menubar.addMenu(widget.native).setText(
+                        widget.name.replace("_", " ")
+                    )
                     _hist.append((name, type(attr), "MenuGui"))
 
                 elif isinstance(widget, ContextMenuGui):
@@ -290,7 +295,9 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
     """
 
     def wrapper(cls_: type[ClassGuiBase]):
-        cls = type(cls_.__name__, (container, ClassGuiBase), {})
+        cls: type[_C | ClassGuiBase] = type(
+            cls_.__name__, (container, ClassGuiBase), {}
+        )
 
         def __init__(
             self: cls,
@@ -323,13 +330,23 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
             self.native.setObjectName(self.name)
             self.native.setWindowTitle(self.name)
 
-        def __setattr__(self: cls, name: str, value: Any):
+        # ui["x"] will not return widget if x is a MagicValueField.
+        # To ensure __getitem__ returns a Widget, this method should be overriden.
+        def __getitem__(self, key):
+            """Get item by integer, str, or slice."""
+            if isinstance(key, str):
+                for widget in self:
+                    if key == widget.name:
+                        return widget
+            return container.__getattr__(self, key)
+
+        def __setattr__(self: cls, name: str, value: Any) -> None:
             if not isinstance(getattr(self.__class__, name, None), MagicField):
                 container.__setattr__(self, name, value)
             else:
                 object.__setattr__(self, name, value)
 
-        def _fast_insert(self: cls, key: int, widget: Widget | Callable):
+        def _fast_insert(self: cls, key: int, widget: Widget | Callable) -> None:
             if isinstance(widget, Callable):
                 # Sometimes uses want to dynamically add new functions to GUI.
                 method_name = getattr(widget, "__name__", None)
@@ -366,8 +383,14 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
                 if isinstance(widget, ClassGuiBase):
                     if self._remove_child_margins:
                         widget.margins = (0, 0, 0, 0)
-                    self.__magicclass_children__.append(widget)
-                    widget._my_symbol = Symbol(widget.name)
+                    if (
+                        len(self.__magicclass_children__) > 0
+                        and widget is not self.__magicclass_children__[-1]
+                    ):
+                        # nested magic classes are already in the list
+                        self.__magicclass_children__.append(widget)
+                        widget._my_symbol = Symbol(widget.name)
+
                     # NOTE: This is not safe. Attributes could collision and macro recording
                     # may break if not correctly named.
 
@@ -424,12 +447,17 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
 
         def reset_choices(self: cls, *_: Any):
             """Reset child Categorical widgets"""
-            for widget in self:
-                if hasattr(widget, "reset_choices"):
-                    widget.reset_choices()
+            all_widgets: set[Widget] = set()
+
+            for item in self._list:
+                widget = getattr(item, "_inner_widget", item)
+                all_widgets.add(widget)
             for widget in self.__magicclass_children__:
-                if hasattr(widget, "reset_choices"):
-                    widget.reset_choices()
+                all_widgets.add(widget)
+
+            for w in all_widgets:
+                if hasattr(w, "reset_choices"):
+                    w.reset_choices()
 
         def close(self: cls):
             current_self = self._search_parent_magicclass()
