@@ -303,3 +303,29 @@ def test_icon():
 
     assert _icon_byte(ui.Menu.a) > 0
     assert _icon_byte(ui.Menu["func"]) > 0
+
+def test_enabled():
+    @magicclass
+    class A:
+        @magicclass
+        class B:
+            a1 = field(int, enabled=False)
+            a2 = vfield(int, enabled=False)
+        b1 = field("b1", enabled=False)
+        b2 = field("b2", enabled=False)
+
+    ui = A()
+    assert not ui[1].enabled
+    assert not ui[2].enabled
+    assert not ui.B[0].enabled
+    assert not ui.B[1].enabled
+
+def test_get_value_field_widget():
+    @magicclass
+    class A:
+        x_1 = field(int)
+        y_1 = vfield(int)
+    ui = A()
+    assert type(ui.y_1) is int
+    assert type(ui["x_1"]) is widgets.SpinBox
+    assert type(ui["y_1"]) is widgets.SpinBox
